@@ -30,11 +30,12 @@ require_once($CFG->dirroot . '/blog/lib.php');
  * @copyright  2014 onwards Ankit Agarwal <ankit.agrr@gmail.com>
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
-class eventobservers_test extends \advanced_testcase {
+final class eventobservers_test extends \advanced_testcase {
     /**
      * Set up method.
      */
     public function setUp(): void {
+        parent::setUp();
         // Enable monitor.
         set_config('enablemonitor', 1, 'tool_monitor');
     }
