@@ -96,6 +96,16 @@ class tool_task_renderer extends plugin_renderer_base {
                         ),
                         'task-runnow'
                     );
+                    $duecontent .= html_writer::div(
+                        html_writer::link(
+                            new moodle_url(
+                                $adhocrunurl,
+                                ['classname' => $classname, 'dueonly' => 1]
+                            ),
+                            get_string('runclassnamedueonly', 'tool_task')
+                        ),
+                        'task-runnow'
+                    );
                 }
 
                 // Mark cell if has failed tasks.
@@ -233,6 +243,7 @@ class tool_task_renderer extends plugin_renderer_base {
      */
     private function generate_adhoc_tasks_simple_table(array $tasks, bool $wantruntasks = false): html_table {
         $adhocrunurl = '/admin/tool/task/run_adhoctasks.php';
+        $adhocdeleteurl = '/admin/tool/task/delete_adhoctasks.php';
         $now = time();
         $failedstr = get_string('failed', 'tool_task');
 
@@ -243,7 +254,9 @@ class tool_task_renderer extends plugin_renderer_base {
             get_string('taskid', 'tool_task'),
             get_string('nextruntime', 'tool_task'),
             get_string('payload', 'tool_task'),
-            $failedstr
+            $failedstr,
+            get_string('faildelay', 'tool_task'),
+            get_string('actions','tool_task'),
         ];
 
         $table->attributes['class'] = 'generaltable';
@@ -263,9 +276,9 @@ class tool_task_renderer extends plugin_renderer_base {
 
             // Mark cell if task has failed.
             $faildelay = $task->get_fail_delay();
-            $faildelaycell = new html_table_cell($faildelay ? $failedstr : '');
+            $failedcell = new html_table_cell($faildelay ? $failedstr : '');
             if ($faildelay) {
-                $faildelaycell->attributes['class'] = 'table-danger';
+                $failedcell->attributes['class'] = 'table-danger';
             }
 
             // Prepares the next run time cell contents.
@@ -293,11 +306,38 @@ class tool_task_renderer extends plugin_renderer_base {
                 }
             }
 
+            // Create fail delay cell.
+            $faildelaycellcontent = $faildelay;
+            $faildelaycell = new html_table_cell($faildelaycellcontent);
+
+            if ($faildelay) {
+                $faildelaycell->attributes['class'] = 'table-danger';
+            }
+
+            // Add delete link with modal trigger.
+            $deletelink = html_writer::link(
+                new moodle_url($adhocdeleteurl, ['taskid' => $taskid, 'sesskey' => sesskey()]),
+                get_string('delete'),
+                [
+                    'class' => 'btn btn-danger',
+                    'role' => 'button',
+                    'aria-label' => get_string('deleteadhoctask', 'tool_task', $taskid),
+                    'data-confirmation' => 'modal',
+                    'data-confirmation-type' => 'delete',
+                    'data-confirmation-title-str' => '["deleteadhoctask", "tool_task", ' . $taskid . ']',
+                    'data-confirmation-content-str' => '["confirmdeletetaskwithid", "tool_task", {"id":'.$taskid.'}]',
+                    'data-confirmation-yes-button-str' => '["delete", "core"]',
+                ]
+            );
+            $deletecell = new html_table_cell($deletelink);
+
             $data[] = new html_table_row([
                 $taskidcell,
                 new html_table_cell($nextrun),
                 new html_table_cell($task->get_custom_data_as_string()),
+                $failedcell,
                 $faildelaycell,
+                $deletecell,
             ]);
         }
         $table->data = $data;
@@ -398,8 +438,8 @@ class tool_task_renderer extends plugin_renderer_base {
                         get_string('runnow', 'tool_task')), 'task-runnow');
             }
 
-            $faildelaycell = new html_table_cell($task->get_fail_delay());
-            if ($task->get_fail_delay()) {
+            if ($faildelay = $task->get_fail_delay()) {
+                $faildelaycell = new html_table_cell(format_time($faildelay));
                 $faildelaycell->text .= html_writer::div(
                     $this->output->single_button(
                         new moodle_url('/admin/tool/task/clear_fail_delay.php',
@@ -409,6 +449,8 @@ class tool_task_renderer extends plugin_renderer_base {
                     'task-runnow'
                 );
                 $faildelaycell->attributes['class'] = 'table-danger';
+            } else {
+                $faildelaycell = new html_table_cell(0);
             }
 
             $row = new html_table_row([
