@@ -39,7 +39,7 @@ require_once(__DIR__.'/fixtures/structure_fixtures.php');
  * @copyright 2010 onwards Eloy Lafuente (stronk7) {@link http://stronk7.com}
  * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
-class basenestedelement_test extends \basic_testcase {
+final class basenestedelement_test extends \basic_testcase {
 
     /**
      * Correct creation tests (attributes and final elements)
