@@ -27,7 +27,7 @@ namespace enrol_database;
  * @copyright  2011 Petr Skoda {@link http://skodak.org}
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
-class sync_test extends \advanced_testcase {
+final class sync_test extends \advanced_testcase {
     protected static $courses = array();
     protected static $users = array();
     protected static $roles = array();
@@ -44,6 +44,7 @@ class sync_test extends \advanced_testcase {
             sqlsrv_configure("LogSubsystems", SQLSRV_LOG_SYSTEM_OFF);
             sqlsrv_configure("LogSeverity", SQLSRV_LOG_SEVERITY_ERROR);
         }
+        parent::tearDownAfterClass();
     }
 
     protected function init_enrol_database() {
@@ -81,11 +82,6 @@ class sync_test extends \advanced_testcase {
                 }
                 break;
 
-            case 'oracle':
-                set_config('dbtype', 'oci8po', 'enrol_database');
-                set_config('dbsybasequoting', '1', 'enrol_database');
-                break;
-
             case 'postgres':
                 set_config('dbtype', 'postgres7', 'enrol_database');
                 $setupsql = "SET NAMES 'UTF-8'";
@@ -150,6 +146,8 @@ class sync_test extends \advanced_testcase {
         $table->add_field('shortname', XMLDB_TYPE_CHAR, '255', null, null, null);
         $table->add_field('idnumber', XMLDB_TYPE_CHAR, '255', null, null, null);
         $table->add_field('category', XMLDB_TYPE_CHAR, '255', null, null, null);
+        $table->add_field('startdate', XMLDB_TYPE_CHAR, '255', null, null, null);
+        $table->add_field('enddate', XMLDB_TYPE_CHAR, '255', null, null, null);
         $table->add_key('primary', XMLDB_KEY_PRIMARY, array('id'));
         if ($dbman->table_exists($table)) {
             $dbman->drop_table($table);
@@ -440,7 +438,6 @@ class sync_test extends \advanced_testcase {
 
         // Test basic enrol sync for one user after login.
 
-        $this->reset_enrol_database();
         $plugin->set_config('localcoursefield', 'idnumber');
         $plugin->set_config('localuserfield', 'idnumber');
         $plugin->set_config('localrolefield', 'shortname');
@@ -798,8 +795,147 @@ class sync_test extends \advanced_testcase {
         $this->assertEquals(1+2+1+4+1+count(self::$courses), $DB->count_records('course'));
         $this->assertTrue($DB->record_exists('course', array('idnumber' => 'ncid9')));
 
-
         // Final cleanup - remove extra tables, fixtures and caches.
         $this->cleanup_enrol_database();
     }
+
+    /**
+     * Test syncing courses with start and end dates.
+     *
+     * @covers \enrol_database_plugin::sync_courses
+     */
+    public function test_sync_courses_start_end_dates(): void {
+        global $DB;
+
+        $this->resetAfterTest();
+        $this->preventResetByRollback();
+        $this->init_enrol_database();
+
+        $courseconfig = get_config('moodlecourse');
+        $nextyear = (int) date('Y') + 1;
+        $prev = (int) date('Y') - 1;
+
+        $midnightstartdate = usergetmidnight(time());
+        $midnightenddate = usergetmidnight(time()) + $courseconfig->courseduration;
+
+        $plugin = enrol_get_plugin('database');
+
+        $trace = new \null_progress_trace();
+
+        $course1 = ['fullname' => 'C1', 'shortname' => 'c1', 'idnumber' => 'c1', 'startdate' => 0,
+            'enddate' => 0];
+        $course2 = ['fullname' => 'C2', 'shortname' => 'c2', 'idnumber' => 'c2', 'startdate' => null,
+            'enddate' => null];
+        // This course won't be created. Broken start date.
+        $course3 = ['fullname' => 'C3', 'shortname' => 'c3', 'idnumber' => 'c3', 'startdate' => 'not date',
+            'enddate' => 0];
+        // This course won't be created. Broken end date.
+        $course4 = ['fullname' => 'C4', 'shortname' => 'c4', 'idnumber' => 'c4', 'startdate' => 0,
+            'enddate' => 'not date'];
+        // This course won't be created. Start date after end date.
+        $course5 = ['fullname' => 'C5', 'shortname' => 'c5', 'idnumber' => 'c5', 'startdate' => '12.05.2024',
+            'enddate' => '12.05.2021'];
+        $course6 = ['fullname' => 'C6', 'shortname' => 'c6', 'idnumber' => 'c6', 'startdate' => '2024-05-22',
+            'enddate' => '2027-05-12'];
+        $course7 = ['fullname' => 'C7', 'shortname' => 'c7', 'idnumber' => 'c7', 'startdate' => null,
+            'enddate' => '12.05.' . $nextyear];
+        $course8 = ['fullname' => 'C8', 'shortname' => 'c8', 'idnumber' => 'c8', 'startdate' => '12.05.2024',
+            'enddate' => null];
+        // This course won't be created. Start date is not set, but it should be set to date after end date.
+        $course9 = ['fullname' => 'C9', 'shortname' => 'c9', 'idnumber' => 'c9', 'startdate' => null,
+            'enddate' => '12.05.' . $prev];
+
+        $DB->insert_record('enrol_database_test_courses', $course1);
+        $DB->insert_record('enrol_database_test_courses', $course2);
+        $DB->insert_record('enrol_database_test_courses', $course3);
+        $DB->insert_record('enrol_database_test_courses', $course4);
+        $DB->insert_record('enrol_database_test_courses', $course5);
+        $DB->insert_record('enrol_database_test_courses', $course6);
+        $DB->insert_record('enrol_database_test_courses', $course7);
+        $DB->insert_record('enrol_database_test_courses', $course8);
+        $DB->insert_record('enrol_database_test_courses', $course9);
+
+        $plugin->set_config('newcoursestartdate', 'startdate');
+        $plugin->set_config('newcourseenddate', 'enddate');
+
+        $plugin->sync_courses($trace);
+
+        // Course 3, course 4, course 5 and course 9 should not be created.
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course1['shortname']]));
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course2['shortname']]));
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course3['shortname']]));
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course4['shortname']]));
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course5['shortname']]));
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course6['shortname']]));
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course7['shortname']]));
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course8['shortname']]));
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course9['shortname']]));
+
+        // Check dates for created courses.
+        $this->assertEquals($midnightstartdate, $DB->get_field('course', 'startdate', ['shortname' => $course1['shortname']]));
+        $this->assertEquals($midnightenddate, $DB->get_field('course', 'enddate', ['shortname' => $course1['shortname']]));
+
+        $this->assertEquals($midnightstartdate, $DB->get_field('course', 'startdate', ['shortname' => $course2['shortname']]));
+        $this->assertEquals($midnightenddate, $DB->get_field('course', 'enddate', ['shortname' => $course2['shortname']]));
+
+        $this->assertEquals(strtotime('22.05.2024'), $DB->get_field('course', 'startdate', ['shortname' => $course6['shortname']]));
+        $this->assertEquals(strtotime('12.05.2027'), $DB->get_field('course', 'enddate', ['shortname' => $course6['shortname']]));
+
+        $this->assertEquals($midnightstartdate, $DB->get_field('course', 'startdate', ['shortname' => $course7['shortname']]));
+        $expected = strtotime('12.05.' . $nextyear);
+        $this->assertEquals($expected, $DB->get_field('course', 'enddate', ['shortname' => $course7['shortname']]));
+
+        $this->assertEquals(strtotime('12.05.2024'), $DB->get_field('course', 'startdate', ['shortname' => $course8['shortname']]));
+        $expected = strtotime('12.05.2024') + $courseconfig->courseduration;
+        $this->assertEquals($expected, $DB->get_field('course', 'enddate', ['shortname' => $course8['shortname']]));
+
+        // Push course with dates as timestamp.
+        $course10 = ['fullname' => 'C10', 'shortname' => 'c10', 'idnumber' => 'c10', 'startdate' => 1810051200,
+            'enddate' => 1810051211];
+        $DB->insert_record('enrol_database_test_courses', $course10);
+
+        $plugin->sync_courses($trace);
+
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course10['shortname']]));
+        $this->assertEquals(1810051200, $DB->get_field('course', 'startdate', ['shortname' => $course10['shortname']]));
+        $this->assertEquals(1810051211, $DB->get_field('course', 'enddate', ['shortname' => $course10['shortname']]));
+
+        // Push course with broken dates, but delete dates from plugin configuration before syncing.
+        $course11 = ['fullname' => 'C11', 'shortname' => 'c11', 'idnumber' => 'c11', 'startdate' => 'not date',
+            'enddate' => 'not date'];
+        $DB->insert_record('enrol_database_test_courses', $course11);
+
+        $plugin->set_config('newcoursestartdate', '');
+        $plugin->set_config('newcourseenddate', '');
+        $plugin->sync_courses($trace);
+
+        $this->assertTrue($DB->record_exists('course', ['shortname' => $course11['shortname']]));
+        $this->assertEquals($midnightstartdate, $DB->get_field('course', 'startdate', ['shortname' => $course11['shortname']]));
+        $this->assertEquals($midnightenddate, $DB->get_field('course', 'enddate', ['shortname' => $course11['shortname']]));
+
+        // Push courses with correct dates, but set date configuration to not existing date fields.
+        $course12 = ['fullname' => 'C12', 'shortname' => 'c12', 'idnumber' => 'c12', 'startdate' => '2024-05-22',
+            'enddate' => '2027-05-12'];
+        $DB->insert_record('enrol_database_test_courses', $course11);
+
+        $plugin->set_config('newcoursestartdate', 'startdate');
+        $plugin->set_config('newcourseenddate', 'ed');
+        $plugin->sync_courses($trace);
+
+        // Course should not be synced to prevent setting up incorrect dates.
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course12['shortname']]));
+
+        $course13 = ['fullname' => 'C13', 'shortname' => 'c13', 'idnumber' => 'c13', 'startdate' => '2024-05-22',
+            'enddate' => '2027-05-12'];
+        $DB->insert_record('enrol_database_test_courses', $course11);
+
+        $plugin->set_config('newcoursestartdate', 'sd');
+        $plugin->set_config('newcourseenddate', 'enddate');
+        $plugin->sync_courses($trace);
+
+        // Course should not be synced to prevent setting up incorrect dates.
+        $this->assertFalse($DB->record_exists('course', ['shortname' => $course13['shortname']]));
+
+        $this->cleanup_enrol_database();
+    }
 }
