@@ -36,7 +36,7 @@ require_once($CFG->dirroot . '/lib/grouplib.php');
  * @copyright  2013 Frédéric Massart
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
-class lib_test extends \advanced_testcase {
+final class lib_test extends \advanced_testcase {
 
     public function test_member_added_event(): void {
         $this->resetAfterTest();
@@ -883,7 +883,7 @@ class lib_test extends \advanced_testcase {
     /**
      * Tests set_groups_messaging
      *
-     * @covers \core_group::set_groups_messaging
+     * @covers ::set_groups_messaging
      */
     public function test_set_groups_messaging(): void {
         $this->resetAfterTest();
@@ -923,7 +923,7 @@ class lib_test extends \advanced_testcase {
     /**
      * Tests set group messaging where it doesn't exist
      *
-     * @covers \core_group::set_groups_messaging
+     * @covers ::set_groups_messaging
      */
     public function test_set_groups_messaging_doesnt_exist(): void {
         $this->resetAfterTest();
