@@ -111,7 +111,6 @@ $string['messagedrawerviewgroupinfo'] = 'Group details for {$a}';
 $string['messagedrawerviewoverview'] = 'Messages overview';
 $string['messagedrawerviewsearch'] = 'Messages search results for {$a}';
 $string['messagedrawerviewsettings'] = 'Message settings';
-$string['messagepreferences'] = 'Message preferences';
 $string['messages'] = 'Messages';
 $string['messagesselected:'] = 'Messages selected:';
 $string['messagetextrequired'] = 'Please enter message text';
@@ -138,8 +137,10 @@ $string['notificationwindow'] = 'Notification window';
 $string['notificationpreferences'] = 'Notification preferences';
 $string['notificationimage'] = 'Notification image';
 $string['notifications'] = 'Notifications';
+$string['notificationsmarkedasread'] = 'All notifications have been marked as read';
 $string['notincontactsheading'] = '{$a} is not in your contacts';
 $string['notincontacts'] = 'You need to add {$a} to your contacts to be able to send them messages.';
+$string['notsupported'] = 'Not supported';
 $string['numparticipants'] = '{$a} participants';
 $string['off'] = 'Off';
 $string['offline'] = 'Offline';
@@ -245,7 +246,10 @@ $string['showmessagewindownonew'] = 'Show message window with no new messages';
 $string['showmessagewindowwithcount'] = 'Show message window with {$a} new messages';
 $string['shownotificationwindownonew'] = 'Show notification window with no new notifications';
 $string['shownotificationwindowwithcount'] = 'Show notification window with {$a} new notifications';
-$string['togglenotificationmenu'] = 'Toggle notifications menu';
+$string['successproviderenabled'] = '\'{$a->provider}\' for \'{$a->processor}\' updated.';
+$string['successproviderlocked'] = '\'{$a->provider}\' for \'{$a->processor}\' locked.';
+$string['successproviderunlocked'] = '\'{$a->provider}\' for \'{$a->processor}\' unlocked.';
+$string['successproviderupdate'] = '\'{$a}\' updated.';
 $string['togglemessagemenu'] = 'Toggle messaging drawer';
 $string['totalconversations'] = '{$a} total conversations';
 $string['touserdoesntexist'] = 'You cannot send a message to a user ID ({$a}) that doesn\'t exist.';
@@ -262,8 +266,9 @@ $string['unreadnotification'] = 'Unread notification: {$a}';
 $string['unreadnotifications'] = 'There are {$a} unread notifications';
 $string['unreadnewgroupconversationmessage'] = 'New message from {$a->name} in {$a->conversationname}';
 $string['unreadnewmessage'] = 'New message from {$a}';
+$string['unsentmessagenotification'] = 'You have an unsent message. It will be lost if you leave this page.';
 $string['useentertosend'] = 'Use enter to send';
-$string['usercantbemessaged'] = 'You can\'t message {$a} due to their message preferences. Try adding them as a contact.';
+$string['usercantbemessaged'] = 'You can\'t message this user due to their message preferences. Try adding them as a contact.';
 $string['userwouldliketocontactyou'] = '{$a} would like to contact you';
 $string['viewfullnotification'] = 'View full notification';
 $string['viewmessageswith'] = 'View messages with {$a}';
@@ -275,3 +280,6 @@ $string['wouldliketocontactyou'] = 'Would like to contact you';
 $string['you'] = 'You:';
 $string['youhaveblockeduser'] = 'You have blocked this user.';
 $string['yourcontactrequestpending'] = 'Your contact request is pending with {$a}';
+
+// Deprecated since Moodle 5.0.
+$string['togglenotificationmenu'] = 'Toggle notifications menu';
