@@ -111,17 +111,15 @@ M.util.CollapsibleRegion = function(Y, id, userpref, strtooltip) {
     var collapsedimage = 't/collapsed'; // ltr mode
     if (right_to_left()) {
         collapsedimage = 't/collapsed_rtl';
-    } else {
-        collapsedimage = 't/collapsed';
     }
     if (this.div.hasClass('collapsed')) {
         // Add the correct image and record the YUI node created in the process
-        this.icon = Y.Node.create('<img src="'+M.util.image_url(collapsedimage, 'moodle')+'" alt="" />');
+        this.icon = Y.Node.create('<img src="'+M.util.image_url(collapsedimage, 'moodle')+'" alt="" class="icon" />');
         // Shrink the div as it is collapsed by default
         this.div.setStyle('height', caption.get('offsetHeight')+'px');
     } else {
         // Add the correct image and record the YUI node created in the process
-        this.icon = Y.Node.create('<img src="'+M.util.image_url('t/expanded', 'moodle')+'" alt="" />');
+        this.icon = Y.Node.create('<img src="'+M.util.image_url('t/expanded', 'moodle')+'" alt="" class="icon" />');
     }
     a.append(this.icon);
 
@@ -196,24 +194,10 @@ M.util.CollapsibleRegion.prototype.div = null;
 M.util.CollapsibleRegion.prototype.icon = null;
 
 /**
- * Makes a best effort to connect back to Moodle to update a user preference,
- * however, there is no mechanism for finding out if the update succeeded.
- *
- * Before you can use this function in your JavsScript, you must have called
- * user_preference_allow_ajax_update from moodlelib.php to tell Moodle that
- * the udpate is allowed, and how to safely clean and submitted values.
- *
- * @param {String} name the name of the setting to update.
- * @param {String} value the value to set it to.
- *
  * @deprecated since Moodle 4.3.
  */
-M.util.set_user_preference = function(name, value) {
-    Y.log('M.util.set_user_preference is deprecated. Please use the "core_user/repository" module instead.', 'warn');
-
-    require(['core_user/repository'], function(UserRepository) {
-        UserRepository.setUserPreference(name, value);
-    });
+M.util.set_user_preference = function() {
+    throw new Error('M.util.set_user_preference is deprecated. Please use the "core_user/repository" module instead.');
 };
 
 /**
@@ -800,14 +784,10 @@ M.util.add_lightbox = function(Y, node) {
     }
 
     node.setStyle('position', 'relative');
+
     var waiticon = Y.Node.create('<img />')
-    .setAttrs({
-        'src' : M.util.image_url(WAITICON.pix, WAITICON.component)
-    })
-    .setStyles({
-        'position' : 'relative',
-        'top' : '50%'
-    });
+        .setAttribute('src', M.util.image_url(WAITICON.pix, WAITICON.component))
+        .addClass('icon');
 
     var lightbox = Y.Node.create('<div></div>')
     .setStyles({
@@ -817,6 +797,7 @@ M.util.add_lightbox = function(Y, node) {
         'height' : '100%',
         'top' : 0,
         'left' : 0,
+        'paddingTop': '50%',
         'backgroundColor' : 'white',
         'textAlign' : 'center'
     })
@@ -845,8 +826,7 @@ M.util.add_spinner = function(Y, node) {
 
     var spinner = Y.Node.create('<img />')
         .setAttribute('src', M.util.image_url(WAITICON.pix, WAITICON.component))
-        .addClass('spinner')
-        .addClass('iconsmall')
+        .addClass('spinner icon')
         .hide();
 
     node.append(spinner);
@@ -1170,7 +1150,8 @@ function stripHTML(str) {
     throw new Error('stripHTML can not be used any more. Please use jQuery instead.');
 }
 
-function updateProgressBar(id, percent, msg, estimate) {
+// eslint-disable-next-line no-unused-vars
+function updateProgressBar(id, percent, msg, estimate, error) {
     var event,
         el = document.getElementById(id),
         eventData = {};
@@ -1182,6 +1163,7 @@ function updateProgressBar(id, percent, msg, estimate) {
     eventData.message = msg;
     eventData.percent = percent;
     eventData.estimate = estimate;
+    eventData.error = error;
 
     try {
         event = new CustomEvent('update', {
