@@ -33,14 +33,16 @@ $string['anonymous_edit'] = 'Record user names';
 $string['anonymous_entries'] = 'Anonymous entries ({$a})';
 $string['anonymous_user'] = 'Anonymous user';
 $string['answerquestions'] = 'Answer the questions';
-$string['append_new_items'] = 'Append new items';
+$string['append_new_items'] = 'Keep existing questions and add new questions at the end';
 $string['autonumbering'] = 'Auto number questions';
 $string['autonumbering_help'] = 'Enables or disables automated numbers for each question';
+$string['availableforallcourses'] = 'Available for all courses';
 $string['average'] = 'Average';
 $string['bold'] = 'Bold';
 $string['calendarend'] = '{$a} closes';
 $string['calendarstart'] = '{$a} opens';
 $string['cannotaccess'] = 'You can only access this feedback from a course';
+$string['cannotcreatepagebreak'] = 'A page break cannot be added at the beginning, and only one page break can be added at the end.';
 $string['cannotsavetempl'] = 'Saving templates is not allowed';
 $string['captcha'] = 'Captcha';
 $string['captchanotset'] = 'Captcha hasn\'t been set.';
@@ -59,10 +61,11 @@ $string['confirmusetemplate'] = 'Are you sure you want to use this template?';
 $string['continue_the_form'] = 'Continue answering the questions';
 $string['count_of_nums'] = 'Count of numbers';
 $string['courseid'] = 'Course ID';
+$string['coursetemplates'] = 'Course templates';
 $string['creating_templates'] = 'Save these questions as a new template';
 $string['delete_entry'] = 'Delete entry';
 $string['delete_item'] = 'Delete question';
-$string['delete_old_items'] = 'Delete old items';
+$string['delete_old_items'] = 'Override existing questions';
 $string['delete_pagebreak'] = 'Delete page break';
 $string['delete_template'] = 'Delete template';
 $string['delete_templates'] = 'Delete template...';
@@ -111,7 +114,7 @@ $string['eventresponsedeleted'] = 'Response deleted';
 $string['eventresponsesubmitted'] = 'Response submitted';
 $string['feedbackcompleted'] = '{$a->username} completed {$a->feedbackname}';
 $string['feedback:addinstance'] = 'Add a new feedback';
-$string['feedbackclose'] = 'Allow answers to';
+$string['feedbackclose'] = 'Allow answers until';
 $string['feedback:complete'] = 'Complete a feedback';
 $string['feedback:createprivatetemplate'] = 'Create private template';
 $string['feedback:createpublictemplate'] = 'Create public template';
@@ -232,6 +235,7 @@ $string['pluginname'] = 'Feedback';
 $string['position'] = 'Position';
 $string['previous_page'] = 'Previous page';
 $string['previewquestions'] = 'Preview questions';
+$string['previewtemplate'] = 'Previewing \'{$a}\' template';
 $string['privacy:metadata:completed'] = 'A record of the submissions to the feedback';
 $string['privacy:metadata:completed:anonymousresponse'] = 'Whether the submission is to be used anonymously.';
 $string['privacy:metadata:completed:timemodified'] = 'The time when the submission was last modified.';
@@ -240,22 +244,24 @@ $string['privacy:metadata:completedtmp'] = 'A record of the submissions which ar
 $string['privacy:metadata:value'] = 'A record of the answer to a question.';
 $string['privacy:metadata:value:value'] = 'The chosen answer.';
 $string['privacy:metadata:valuetmp'] = 'A record of the answer to a question in a submission in progress.';
-$string['public'] = 'Public';
 $string['question'] = 'Question';
 $string['questionandsubmission'] = 'Question and submission settings';
+$string['questionmoved'] = 'Question moved';
 $string['questions'] = 'Questions';
 $string['questionslimited'] = 'Showing only {$a} first questions, view individual answers or download table data to view all.';
 $string['radio'] = 'Multiple choice - single answer';
 $string['radio_values'] = 'Responses';
 $string['ready_feedbacks'] = 'Ready feedbacks';
 $string['required'] = 'Required';
-$string['resetting_data'] = 'Reset feedback responses';
+$string['resetting_data'] = 'Responses';
+$string['resetting_delete'] = 'Delete responses';
 $string['resetting_feedbacks'] = 'Resetting feedbacks';
+$string['responded'] = 'Responded';
 $string['response_nr'] = 'Response number';
 $string['responses'] = 'Responses';
 $string['responsetime'] = 'Responses time';
 $string['save_as_new_item'] = 'Save as new question';
-$string['save_as_new_template'] = 'Save as new template';
+$string['save_as_new_template'] = 'Save as template';
 $string['save_entries'] = 'Submit your answers';
 $string['save_item'] = 'Save question';
 $string['saving_failed'] = 'Saving failed';
@@ -272,6 +278,7 @@ $string['show_entries'] = 'Show responses';
 $string['show_entry'] = 'Show response';
 $string['show_nonrespondents'] = 'Show non-respondents';
 $string['site_after_submit'] = 'Site after submit';
+$string['sitetemplates'] = 'Site templates';
 $string['sort_by_course'] = 'Sort by course';
 $string['started'] = 'Started';
 $string['startedon'] = 'Started on {$a}';
@@ -289,13 +296,16 @@ $string['textfield'] = 'Short text answer';
 $string['textfield_maxlength'] = 'Maximum characters accepted';
 $string['textfield_size'] = 'Textfield width';
 $string['there_are_no_settings_for_recaptcha'] = 'There are no settings for captcha';
-$string['this_feedback_is_already_submitted'] = 'You\'ve already completed this activity.';
+$string['this_feedback_is_already_submitted'] = 'You have already submitted this feedback.';
 $string['typemissing'] = 'Missing value "type"';
 $string['update_item'] = 'Save changes to question';
 $string['url_for_continue'] = 'Link to next activity';
 $string['url_for_continue_help'] = 'After submitting the feedback, a continue button is displayed, which links to the course page. Alternatively, it may link to the next activity if the URL of the activity is entered here.';
 $string['use_one_line_for_each_value'] = 'Use one line for each answer!';
-$string['use_this_template'] = 'Use this template';
+$string['use_this_template'] = 'Use template';
 $string['using_templates'] = 'Use a template';
 $string['vertical'] = 'Vertical';
-$string['whatfor'] = 'What do you want to do?';
+$string['whatfor'] = 'How would you like to apply the template?';
+
+// Deprecated since Moodle 4.5.
+$string['public'] = 'Public';
