@@ -16,7 +16,7 @@
 // along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
 
 /**
- * Strings for component 'forum', language 'en', branch 'MOODLE_20_STABLE'
+ * Strings for component 'mod_forum', language 'en', branch 'MOODLE_20_STABLE'
  *
  * @package   mod_forum
  * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
@@ -530,9 +530,6 @@ $string['postmailinfo'] = 'This is a copy of a message posted in {$a}.';
 $string['postmailnow'] = '<p>This post will be mailed out immediately to all forum subscribers.</p>';
 $string['postmailreply'] = 'To reply click on this link: {$a}';
 $string['postmailsubject'] = '{$a->courseshortname}: {$a->subject}';
-$string['postrating1'] = 'Mostly separate knowing';
-$string['postrating2'] = 'Separate and connected';
-$string['postrating3'] = 'Mostly connected knowing';
 $string['posts'] = 'Posts';
 $string['postsfrom'] = 'Posts from';
 $string['postsmadebyuser'] = 'Posts made by {$a}';
@@ -600,9 +597,6 @@ $string['privacy:metadata:preference:markasreadonnotification'] = 'Whether to ma
 $string['privacy:metadata:preference:trackforums'] = 'Whether to enable read tracking.';
 $string['privacy:postwasread'] = 'This post was first read on {$a->firstread} and most recently read on {$a->lastread}';
 $string['privacy:readtrackingdisabled'] = 'You have chosen to not track posts you have read within this forum.';
-$string['privacy:request:delete:discussion:name'] = 'Delete at the request of the author';
-$string['privacy:request:delete:post:message'] = 'The content of this post has been deleted at the request of its author.';
-$string['privacy:request:delete:post:subject'] = 'Delete at the request of the author';
 $string['privacy:subscribedtoforum'] = 'You are subscribed to this forum.';
 $string['privatereply'] = 'Reply privately';
 $string['privatereply_help'] = 'When you reply privately, your post is also visible to users with the capability to view private replies, such as teachers.';
@@ -614,9 +608,8 @@ $string['prunedpost'] = 'A new discussion has been created from that post';
 $string['pruneheading'] = 'Split the discussion and move this post to a new discussion';
 $string['qandaforum'] = 'Q and A forum';
 $string['qandanotify'] = 'This is a question and answer forum. To see other replies, you must first post your reply.';
-$string['re'] = 'Re:';
 $string['readtherest'] = 'Read the rest of this topic';
-$string['removeallforumtags'] = 'Remove all forum tags';
+$string['removeallforumtags'] = 'All forum tags';
 $string['removefromfavourites'] = 'Unstar this discussion';
 $string['replies'] = 'Replies';
 $string['repliesmany'] = '{$a} replies so far';
@@ -631,10 +624,10 @@ $string['replytouser'] = 'Use email address in reply';
 $string['reply_handler'] = 'Reply to forum posts via email';
 $string['reply_handler_name'] = 'Reply to forum posts';
 $string['resetforums'] = 'Delete posts from';
-$string['resetforumsall'] = 'Delete all posts';
-$string['resetdigests'] = 'Delete all per-user forum digest preferences';
-$string['resetsubscriptions'] = 'Delete all forum subscriptions';
-$string['resettrackprefs'] = 'Delete all forum tracking preferences';
+$string['resetforumsall'] = 'All posts';
+$string['resetdigests'] = 'All per-user forum digest preferences';
+$string['resetsubscriptions'] = 'All forum subscriptions';
+$string['resettrackprefs'] = 'All forum tracking preferences';
 $string['rsssubscriberssdiscussions'] = 'RSS feed of discussions';
 $string['rsssubscriberssposts'] = 'RSS feed of posts';
 $string['rssarticles'] = 'Number of RSS recent articles';
@@ -707,7 +700,6 @@ $string['subscriptionauto'] = 'Auto subscription';
 $string['subscriptiondisabled'] = 'Subscription disabled';
 $string['subscriptions'] = 'Subscriptions';
 $string['tagarea_forum_posts'] = 'Forum posts';
-$string['tagsdeleted'] = 'Forum tags have been deleted';
 $string['thisforumisthrottled'] = 'This forum has a limit to the number of forum postings you can make in a given time period - this is currently set at {$a->blockafter} posting(s) in {$a->blockperiod}';
 $string['thisforumisdue'] = 'The due date for posting to this forum was {$a}.';
 $string['thisforumhasduedate'] = 'The due date for posting to this forum is {$a}.';
@@ -786,15 +778,16 @@ $string['gradeitemnameforwholeforum'] = '{$a->name} whole forum';
 $string['gradeitemnameforrating'] = '{$a->name} rating';
 $string['grades:gradesavedfor'] = 'Grade saved for {$a->fullname}';
 $string['grades:gradesavefailed'] = 'Unable to save grade for {$a->fullname}: {$a->error}';
-$string['notgraded'] = 'Not graded';
 $string['nousersmatch'] = 'No user(s) found for given criteria';
 $string['showmoreusers'] = 'Show more users';
 $string['viewconversation'] = 'View discussion';
 $string['viewgrades'] = 'View grades';
 
-// Deprecated since Moodle 4.3.
-$string['completionpostsgroup'] = 'Require posts';
-$string['completiondiscussionsgroup'] = 'Require discussions';
-$string['completiondiscussionshelp'] = 'requiring discussions to complete';
-$string['completionrepliesgroup'] = 'Require replies';
-$string['completionreplieshelp'] = 'requiring replies to complete';
+// Deprecated since Moodle 4.5.
+$string['privacy:request:delete:discussion:name'] = 'Delete at the request of the author';
+$string['privacy:request:delete:post:message'] = 'The content of this post has been deleted at the request of its author.';
+$string['privacy:request:delete:post:subject'] = 'Delete at the request of the author';
+$string['tagsdeleted'] = 'Forum tags have been deleted';
+
+// Deprecated since Moodle 5.0.
+$string['re'] = 'Re:';
