@@ -17,6 +17,7 @@
 namespace mod_quiz\question\bank;
 
 use context_module;
+use core_question\local\bank\version_options;
 use core_question\local\bank\question_version_status;
 use core_question\local\bank\random_question_loader;
 use core_question\question_reference_manager;
@@ -46,25 +47,14 @@ class qbank_helper {
      * @return stdClass[] other versions of this question. Each object has fields versionid,
      *       version and questionid. Array is returned most recent version first.
      */
+    #[\core\attribute\deprecated(
+        'core_question\local\bank::get_version_options',
+        since: 5.0,
+        mdl: 'MDL-77713')
+    ]
     public static function get_version_options(int $questionid): array {
-        global $DB;
-
-        return $DB->get_records_sql("
-                SELECT allversions.id AS versionid,
-                       allversions.version,
-                       allversions.questionid
-
-                  FROM {question_versions} allversions
-
-                 WHERE allversions.questionbankentryid = (
-                            SELECT givenversion.questionbankentryid
-                              FROM {question_versions} givenversion
-                             WHERE givenversion.questionid = ?
-                       )
-                   AND allversions.status <> ?
-
-              ORDER BY allversions.version DESC
-              ", [$questionid, question_version_status::QUESTION_STATUS_DRAFT]);
+        \core\deprecation::emit_deprecation_if_present([self::class, __FUNCTION__]);
+        return version_options::get_version_options($questionid);
     }
 
     /**
@@ -85,7 +75,7 @@ class qbank_helper {
      * @return array indexed by slot, with information about the content of each slot.
      */
     public static function get_question_structure(int $quizid, context_module $quizcontext,
-            int $slotid = null): array {
+            ?int $slotid = null): array {
         global $DB;
 
         $params = [
@@ -139,6 +129,7 @@ class qbank_helper {
              -- version we could consider digging the old code out of git history from
              -- just before the commit that added this comment.
              -- For relevant question_bank_entries, this gets the latest non-draft slot number.
+             -- TODO: Optimise the query, as Oracle-specific constraints no longer apply.
              LEFT JOIN (
                    SELECT lv.questionbankentryid,
                           MAX(CASE WHEN lv.status <> :draft THEN lv.version END) AS usableversion,
@@ -198,6 +189,7 @@ class qbank_helper {
                 $slot->length = 1;
             } else if (!\question_bank::qtype_exists($slot->qtype)) {
                 // Question of unknown type found in the database. Set to placeholder question types instead.
+                $slot->originalqtype = $slot->qtype;
                 $slot->qtype = 'missingtype';
             } else {
                 $slot->_partiallyloaded = 1;
