@@ -32,7 +32,7 @@ require_once($CFG->dirroot . '/question/engine/tests/helpers.php');
  * @copyright 2013 Jean-Michel Vedrine
  * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
  */
-class walkthrough_test extends \qbehaviour_walkthrough_test_base {
+final class walkthrough_test extends \qbehaviour_walkthrough_test_base {
 
     public function test_deferred_feedback_unanswered(): void {
 
