@@ -26,7 +26,7 @@ use core_user;
  * @copyright  2023 Stephan Robotta <stephan.robotta@bfh.ch>
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later.
  */
-class renderable_test extends \advanced_testcase {
+final class renderable_test extends \advanced_testcase {
     /**
      * @var int The course with separate groups.
      */
@@ -265,6 +265,7 @@ class renderable_test extends \advanced_testcase {
      * @throws \coding_exception
      */
     public function setUp(): void {
+        parent::setUp();
         $this->resetAfterTest();
         $this->courses[self::COURSE_SEPARATE_GROUP] = $this->getDataGenerator()->create_course(['groupmode' => SEPARATEGROUPS]);
         $this->courses[self::COURSE_VISIBLE_GROUP] = $this->getDataGenerator()->create_course(['groupmode' => VISIBLEGROUPS]);
@@ -318,7 +319,7 @@ class renderable_test extends \advanced_testcase {
      * @return void
      */
     public function test_get_user_list(int $courseindex, string $username, array $expectedusers,
-        string $groupname = null): void {
+        ?string $groupname = null): void {
         global $PAGE, $CFG;
         $currentcourse = $this->courses[$courseindex];
         $PAGE->set_url('/report/log/index.php?id=' . $currentcourse->id);
